@@ -18,13 +18,15 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: pipe.c,v 1.7 2005/11/04 09:56:14 evertonm Exp $ */
+/* $Id: pipe.c,v 1.8 2006/04/18 12:10:15 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <assert.h>
 
 #include "pipe.h"
+#include "common.h"
+#include "conf.h"
 
 void nepim_pipe_set_init(nepim_pipe_set_t *set)
 {
@@ -60,3 +62,21 @@ void nepim_pipe_set_del(nepim_pipe_set_t *set, int sd)
   nepim_array_del(&set->array, sd);
 }
 
+void nepim_pipe_schedule_keepalive_timer(nepim_pipe_t *pipe,
+					 oop_call_time *on_tcp_keepalive_require)
+{
+  nepim_session_t *session = &pipe->session;
+
+  assert(session->keepalive_require);
+
+  {
+    int result = gettimeofday(&session->tv_keepalive_recv_timer, 0);
+    assert(!result);
+  }
+  nepim_timer_usec_add(&session->tv_keepalive_recv_timer, 
+                       nepim_global.tcp_keepalive_recv_timer);
+
+  nepim_global.oop_src->on_time(nepim_global.oop_src,
+                                session->tv_keepalive_recv_timer,
+                                on_tcp_keepalive_require, pipe);
+}
