@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: slot.c,v 1.43 2006/06/02 01:24:50 evertonm Exp $ */
+/* $Id: slot.c,v 1.44 2006/06/05 15:52:01 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -199,7 +199,8 @@ static void slot_buf_write(nepim_slot_t *slot, char *buf, size_t buf_size, uint8
   case UDP_TYPE_DATA:
 
     /* modifies 'session->seed' */
-    fill_packet_data(&(slot->session), buf, UDP_HEADER_LEN, buf_size);
+    fill_packet_data(&(slot->session), (unsigned char *) buf,
+		     UDP_HEADER_LEN, buf_size);
 
     hdr.seq = ++slot->seq;
 
