@@ -18,11 +18,13 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: str.c,v 1.5 2006/06/02 13:18:32 evertonm Exp $ */
+/* $Id: str.c,v 1.8 2006/06/12 14:58:32 evertonm Exp $ */
 
 #include <stdlib.h>
+#include <stdio.h>
 #include <string.h>
 #include <ctype.h>
+#include <errno.h>
 #include <assert.h>
 
 #include "str.h"
@@ -166,3 +168,98 @@ int addr_split_port(char *buf, int buf_size, char **port)
 {
   return nepim_str_split_comma(buf, buf_size, port);
 }
+
+static int multiplier_affix(const char *str)
+{
+  const char *i;
+  int multiplier = 1;
+
+  assert(str);
+
+  for (i = str; ; ++i) {
+    char c = *i;
+    if (!c)
+      break;
+    switch (c) {
+    case 'k':
+    case 'K':
+      multiplier *= 1000;
+      break;
+    case 'm':
+    case 'M':
+      multiplier *= 1000000;
+      break;
+    case 'g':
+    case 'G':
+      multiplier *= 1000000000;
+      break;
+    }
+  }
+
+  return multiplier;
+}
+
+static int parse_float(float *f, const char *str)
+{
+  return (sscanf(str, "%f", f) != 1);
+}
+
+long long nepim_unit_ll(const char *str)
+{
+  float f;
+
+  if (parse_float(&f, str))
+    return strtoll(str, 0, 10) * (long long) multiplier_affix(str);
+
+  return f * multiplier_affix(str);
+}
+
+int nepim_unit_int(const char *str)
+{
+  float f;
+
+  if (parse_float(&f, str))
+    return atoi(str) * multiplier_affix(str);
+
+  return f * multiplier_affix(str);
+}
+
+static int time_affix(const char *str)
+{
+  const char *i;
+  int multiplier = 1;
+
+  assert(str);
+
+  for (i = str; ; ++i) {
+    char c = *i;
+    if (!c)
+      break;
+    switch (c) {
+    case 'm':
+    case 'M':
+      multiplier *= 60;
+      break;
+    case 'h':
+    case 'H':
+      multiplier *= 3600;
+      break;
+    case 'd':
+    case 'D':
+      multiplier *= 86400;
+      break;
+    }
+  }
+
+  return multiplier;
+}
+
+int nepim_time_unit(const char *str)
+{
+  float f;
+
+  if (parse_float(&f, str))
+    return atoi(str) * time_affix(str);
+
+  return f * time_affix(str);
+}
