@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: str.h,v 1.4 2006/06/02 13:18:32 evertonm Exp $ */
+/* $Id: str.h,v 1.6 2006/06/12 14:58:32 evertonm Exp $ */
 
 #ifndef NEPIM_STR_H
 #define NEPIM_STR_H
@@ -31,4 +31,8 @@ int addr_list_get(const char *list, int i, char *buf, int buf_size);
 char *addr_list_append(char *list, const char *tail);
 int addr_split_port(char *buf, int buf_size, char **port);
 
+long long nepim_unit_ll(const char *str);
+int nepim_unit_int(const char *str);
+int nepim_time_unit(const char *str);
+
 #endif /* NEPIM_STR_H */
