@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: tcpwrap.c,v 1.6 2005/11/04 09:56:15 evertonm Exp $ */
+/* $Id: tcpwrap.c,v 1.7 2006/06/05 10:20:54 evertonm Exp $ */
 
 #include <stdio.h>
 #include <assert.h>
@@ -36,10 +36,10 @@ MA 02110-1301 USA
 # define RTLD_LAZY 0x00001
 #endif
 
-typedef int (*nepim_hosts_ctl_t)(char *daemon,
-				 char *client_name,
-				 char *client_addr,
-				 char *client_user);
+typedef int (*nepim_hosts_ctl_t)(const char *daemon,
+				 const char *client_name,
+				 const char *client_addr,
+				 const char *client_user);
 
 static void              *libwrap        = 0;
 static nepim_hosts_ctl_t local_hosts_ctl = 0;
